@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20140228';
+our $VERSION = '0.20140328';
 
-# Table last modified: 2014-02-28
+# Table last modified: 2014-03-28
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -105,10 +105,10 @@ our %ZIP_TABLE = (
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:7[1-3]|3[013589]|6\d|0[2358]|8[125-9]|5[18]|4[014]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|8[2358]|0[13]|1[014-69]|2[278]|3[2-4])|3(?:66|70|5[015]|2[1245]|3[138]|0[237]|4[15]|1[01]|8[038])|6(?:55|2[019]|6[356]|0[1268]|7[67]|1[07]|3[129]|4[049])|5(?:11|4[03]|0[1-35-7]|5[058]|2[02]|6[07]|8[58]|7[57])|4(?:02|5[06]|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
     '101' => '(?:8(?:4(?:7[05-7]|8[13]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|8[1568]|1[0-2459]|7[6-9]|4[2-58]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|3(?:6[2356]|0[1257-9]|4[5-7]|8[01358]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026])|9(?:[01]1|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[0359])|101))',
-    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|8[124-8]|5[0-25]|3[0-289]|7[0-25-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:41|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:30|77|8[0-35]|2[45]|0[58]|1[125689])|79[58]))',
+    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|8[124-8]|5[0-25]|3[0-289]|7[0-25-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:41|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:30|77|8[0-35]|2[4-6]|0[58]|1[125689])|79[58]))',
     '103' => '(?:8(?:2(?:0[1-6]|5[0-259]|1[0-2478]|6[0135]|8[2457]|7[02358]|4[0-3578]|3[0-8]|2[124589])|4(?:7[0-3]|2[2-7]|0[1-57]|4[38]|3[02-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|5(?:0[1-367]|8[4-689]|2[0-25]|6[67]|5[24-68]|3[13-8]|4[238]|1[0-2]|7[017])|6(?:40|7[067]|6[068]|8[0469]|5[0-36]|3[1269])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-24-8]|1[14-7])|4(?:1[035689]|3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-579])|5(?:1[028]|3[0135689]|5[013-689]|4[0468]|7[02]|6[036-8]|2[0136-8]|0[1256]|8[014578])|3(?:7[027-9]|1[0-3579]|8[01368]|4[045]|2[014589]|5[167]|6[05]|3[02358]|0[1-59])|2(?:40|1[0-258]|7[17]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-3]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|4[015-9]|3[02-7]|1[0-24-69])|5(?:6[03578]|4[0356]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:88|0[127]|1[1267]))|6050|7444))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-24-8]|1[14-7])|4(?:1[035689]|3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-579])|3(?:7[027-9]|1[0-3579]|8[01368]|2[014589]|5[167]|6[05]|0[1-579]|3[02358]|4[0-5])|5(?:1[028]|3[0135689]|5[013-689]|7[02]|6[036-8]|4[03468]|2[0136-8]|0[1256]|8[014578])|2(?:40|1[0-258]|7[17]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '105' => '(?:(?:8(?:4(?:7[0-3]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|4[015-9]|3[02-7]|1[0-24-69])|5(?:6[03578]|4[0356]|2[0-357-9]|1[0-2578]|0[257-9]|8[0-57-9]|7[4-9]|5[03-8]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:88|0[127]|1[1267]))|6050|7444))',
     '106' => '(?:(?:8(?:5(?:08|6[0-35-79]|7[136-8]|1[458]|4[13-5]|2[12]|3[1257]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|3[069])|0(?:[01]1|39)|401|797)|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:5(?:32|8[135]|5[026-8]|2[0-2578]|7[07]|6[037]|0[258]|1[15]|4[56])|6(?:50|8[06]|2[03578]|0[14]|1[5-79]|7[46]|3[0-3689]|6[68])|4(?:20|34|56|77|0[134]|8[24]|1[0-246-9]|4[08]|6[06-8])|3(?:55|4[028]|7[013]|2[0346]|6[09]|8[048]|3[026])|0(?:06|60|77)))',
     '108' => '(?:(?:8(?:5(?:7[1358]|1[0-25]|4[03-578]|5[0-35-9]|6[048]|3[0236]|0[12579]|2[035]|8[0-3568])|3(?:2[25689]|3[0348]|5[058]|8[0134689]|1[35]|6[01]|4[15]|7[02389]|0[3578])|2(?:7[056]|0[128]|8[02]|3[0-4]|5[05]|2[12]|4[0-2]|1[017])|4(?:[56]6|85|0[3-57]|3[09]|2[013-5]|7[078]|1[014-7]|4[48])|6(?:50|3[2356]|0[1267]|1[0-25-7]|2[28]|4[0-268])|0(?:[17]1|[25]0|8[08]|0[15])|7(?:1[03]|0[137])|117)|63(?:50|63)))',
@@ -130,8 +130,8 @@ our %ZIP_TABLE = (
     '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:[25]0|8[3-578]|7[025]|0[13]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-35])|2(?:10|22)|080))',
-    '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|7[0157]|2[0267]|4[08]|1[125]|0[3578])|7(?:[23]3|11)|405|880|908))',
+    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:[25]0|8[3-578]|7[025]|0[13]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-37]|0[17]|1[0178])|1(?:81|1[0-35])|2(?:10|22)|080))',
+    '136' => '(?:8(?:5(?:4[03]|8[01589]|1[2357]|3[13]|7[057]|6[07]|5[05]|0[1257]|2[1-35])|6(?:[68]6|3[057]|7[0157]|2[0267]|4[08]|1[125]|0[3578])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|8[03]|3[0136-9]|7[1-36]|6[0367]|2[013569]|0[25-8]|5[0-28]|1[1256])|6(?:01|7[02578]|4[04]|6[0168]|1[13-79]|2[13568]|3[01479]|8[0278]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
     '141' => '(?:8(?:6(?:3[017-9]|2[01379]|4[02-46-8]|0[2-6]|8[048]|6[03-5]|7[1-39]|1[01356]|5[06-8])|5(?:34|4[04]|0[13-578]|5[59]|2[0-25]|1[02579]|6[0-25-8]|8[0248]|7[267])|4(?:2[0-3]|1[1-9])|7(?:0[17]|1[05])|001))',
@@ -140,7 +140,7 @@ our %ZIP_TABLE = (
     '144' => '(?:8(?:5(?:44|5[015]|8[018]|3[0-356]|7[057]|2[25]|1[01356]|0[56])|6(?:02|11|2[1-3]|5[056]|7[78]|6[01])))',
     '145' => '(?:85(?:[23]3|58|66|0[16]|1[15]))',
     '146' => '(?:8(?:5(?:22|31|67|5[158]|8[058]|1[0-25]|7[67]|0[15]|4[034])|6(?:[03]1|10|77|2[03]|5[056]|6[68])))',
-    '150' => '(?:8(?:5(?:45|6[37]|2[25]|5[0-25]|8[5-8]|7[57]|1[0-24-7]|0[2357-9]|3[038])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
+    '150' => '(?:8(?:5(?:45|5[0-35]|6[37]|2[25]|8[5-8]|7[57]|1[0-24-7]|0[2357-9]|3[038])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|9[0-2]|5[24589]|7[0-46-8]|0[2-579])|6(?:7[1-7]|0[01])|40[14]))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:6[05-7]|7[1378]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[018]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
@@ -211,7 +211,7 @@ our %ZIP_TABLE = (
     '226' => '(?:85(?:[25]5|70|1[02]|0[1-37]))',
     '227' => '(?:85(?:22|40|0[1258]|1[28]))',
     '230' => '(?:8(?:5(?:11|7[17]|0[14]|5[05])|6(?:[68]6|11|28)|765))',
-    '231' => '(?:8(?:3(?:43|3[018]|2[0134]|1[0-6])|5(?:[25]0|42|6[26]|3[46]|8[08])|4(?:[38]4|45|61|1[19]|7[078])|0(?:80|0[18])|6(?:16|54|82)|7(?:11|7[12])|966))',
+    '231' => '(?:8(?:3(?:43|3[018]|2[0134]|1[0-6])|5(?:[25]0|42|6[26]|8[058]|3[46])|4(?:[38]4|45|61|1[19]|7[078])|0(?:80|0[18])|6(?:16|54|82)|7(?:11|7[12])|966))',
     '232' => '(?:8(?:5(?:15|31|76|8[057]|5[58])|6(?:02|88)))',
     '233' => '(?:85(?:0[1-3]|5[056]))',
     '235' => '(?:85(?:58|2[23]|0[15]))',
@@ -233,15 +233,15 @@ our %ZIP_TABLE = (
     '251' => '(?:8(?:5(?:22|40|5[0158]|3[0134]|1[0135]|6[067]|8[18]|0[125])|601))',
     '252' => '(?:(?:5(?:2(?:01|33|77|8[0568]|1[01]|2[125]|5[0258]|9[2-578])|1(?:[56]2|8[13589]|7[27]|9[1256]))|0(?:3(?:7[03-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|[47]0|11|85|3[89]|6[67]|5[08])|119[235]))',
     '253' => '(?:(?:8(?:5(?:01|10|22|43|67|7[17]|8[58]|5[05]|3[01])|686)|019[256]))',
-    '254' => '(?:8(?:5(?:43|55|67|8[58]|0[12]|3[023])|6(?:01|86|1[024])))',
+    '254' => '(?:8(?:5(?:43|55|6[27]|0[12]|3[023]|8[589])|6(?:01|86|1[024])))',
     '255' => '(?:8555)',
     '256' => '(?:8510)',
     '257' => '(?:85(?:[23]3|11|55|66|8[458]|0[12]))',
     '258' => '(?:(?:85(?:11|85|3[38]|0[16])|0195))',
     '259' => '(?:(?:1(?:1(?:8[58]|9[235-8])|29[23]|392)|0(?:1(?:9[2-46-8]|8[01])|39[2356])))',
-    '260' => '(?:8(?:6(?:0[13467]|5[46]|4[2578]|2[0-24679]|6[0-35-8]|7[0-357]|8[258]|3[135-7]|1[02389])|5(?:40|2[134]|8[0568]|7[257]|0[1-9]|3[2458]|1[0-68]|5[01457-9]|6[02-7])|7(?:3[03]|1[02357]|0[137]|2[02])))',
+    '260' => '(?:8(?:6(?:0[13467]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7]|1[02389])|5(?:40|7[0257]|2[134]|8[0568]|0[1-9]|3[4-68]|5[1457-9]|6[0-467]|1[0-3568])|7(?:3[03]|1[02357]|0[137]|2[02])))',
     '261' => '(?:8(?:5(?:66|75|3[03]|4[45]|5[2458]|1[0235]|0[1-478]|2[0-2]|8[125-8])|6(?:09|86)|733))',
-    '262' => '(?:8(?:5(?:1[0-2]|0[236])|733))',
+    '262' => '(?:8(?:5(?:0[26]|1[0-2])|733))',
     '263' => '(?:8(?:5(?:[12]2|33|77|8[58]|5[05]|0[56])|733))',
     '264' => '(?:8(?:5(?:[135]0|8[25]|0[15])|6(?:04|46)|733))',
     '265' => '(?:8501)',
@@ -253,14 +253,14 @@ our %ZIP_TABLE = (
     '274' => '(?:8(?:5(?:[12]0|77|85|3[03]|0[13-7]|5[58])|601))',
     '275' => '(?:8(?:5(?:11|28|33|60|8[058]|7[25-7])|6(?:[01]1|66)))',
     '276' => '(?:85(?:01|80|2[34]))',
-    '277' => '(?:8(?:5(?:1[158]|0[13-57]|7[07]|6[156]|5[0146-8]|8[125-9]|3[139]|2[12])|6(?:86|5[45]|6[16])))',
+    '277' => '(?:8(?:5(?:1[1589]|0[13-57]|7[07]|5[0146-8]|8[125-9]|3[139]|6[14-6]|2[0-2])|6(?:86|5[45]|6[16])))',
     '278' => '(?:8(?:5(?:[02]1|10|33|77|5[05])|6(?:01|86)))',
     '279' => '(?:8(?:5(?:30|41|67|5[0358]|8[58]|1[1689]|2[124-79]|0[1-35])|6(?:01|86)))',
     '282' => '(?:86(?:02|10))',
     '283' => '(?:(?:8(?:5(?:[01]1|55|88)|6(?:50|86))|0195))',
     '284' => '(?:8555)',
     '285' => '(?:8(?:5(?:33|50|67|8[0568]|2[0-2]|1[01]|0[1-359])|6(?:19|55)|765))',
-    '286' => '(?:(?:85(?:[02]1|8[58])|029[23]))',
+    '286' => '(?:(?:85(?:[02]1|8[58])|0292))',
     '287' => '(?:(?:8(?:5(?:[58]5|10|0[1-3])|601)|0292))',
     '288' => '(?:8601)',
     '289' => '(?:(?:1(?:59[2-4]|[138]92|29[78]|69[23]|79[23])|0(?:[124-6]92|39[23])|2(?:19[278]|292|595)))',
@@ -278,7 +278,7 @@ our %ZIP_TABLE = (
     '302' => '(?:(?:85(?:0[12]|8[56])|0198))',
     '303' => '(?:850[13])',
     '304' => '(?:8[56]01)',
-    '305' => '(?:8(?:5(?:[58]5|6[1-9]|2[01]|1[56]|0[1346])|6(?:42|0[1249]|8[67])))',
+    '305' => '(?:8(?:5(?:[58]5|77|6[1-9]|2[01]|1[56]|0[1346])|6(?:42|0[1249]|8[67])))',
     '306' => '(?:(?:0(?:49[235]|[36]92|595)|86(?:01|86)))',
     '307' => '(?:8(?:50[12]|601))',
     '308' => '(?:(?:8(?:5(?:40|2[1-4]|1[0-3])|6(?:[03]8|16))|019[34]))',
@@ -324,7 +324,7 @@ our %ZIP_TABLE = (
     '348' => '(?:8(?:5(?:[258]5|30|1[23]|0[1-35-8]|4[09])|601))',
     '349' => '(?:(?:0(?:19[23568]|29[2-4])|1(?:19[23]|292)))',
     '350' => '(?:(?:0(?:2(?:9[25]|8[03-9])|39[2-6]|49[3-6]|19[237])|1(?:1(?:9[24-8]|8[18])|3(?:9[28]|8[08])|29[25-8])|8(?:5(?:31|8[58]|5[05]|0[18]|1[01])|6(?:01|66))|22(?:92|8[0178])))',
-    '351' => '(?:(?:8(?:5(?:[26]0|51|0[18]|1[01]|8[56])|601)|01(?:88|9[2-46-8])))',
+    '351' => '(?:(?:8(?:5(?:[26]0|0[18]|5[15]|1[01]|8[56])|601)|01(?:88|9[2-46-8])))',
     '352' => '(?:8(?:5(?:01|10|23|49|8[89]|7[27]|5[58])|6(?:23|66)))',
     '353' => '(?:85(?:01|55))',
     '354' => '(?:85(?:33|77|8[05]|5[58]|1[01]|0[145]))',
@@ -372,7 +372,7 @@ our %ZIP_TABLE = (
     '396' => '(?:(?:8(?:5(?:01|85|5[058]|1[01])|6(?:09|82|1[17]))|0(?:198|293)))',
     '397' => '(?:(?:8(?:5(?:67|71|8[58]|5[05])|60[29])|0[23]92))',
     '398' => '(?:8(?:6(?:86|0[12])|501))',
-    '399' => '(?:(?:8(?:7(?:44|60|2[0-258]|5[0145]|1[0-2]|3[0389]|0[1-37])|2(?:9[2357]|8[1-3568])|3(?:86|92)|69[56]|192)|4(?:5(?:6[4-8]|8[13-9]|9[2-578]|7[0-3568])|69[235-7]|39[2-5]|19[25]|498)|0(?:7(?:9[56]|8[1256])|49[235-8]|29[235])|3(?:19[23]|295|797|892)|1(?:392|511|689|895)|9(?:192|393|494)|719[24]))',
+    '399' => '(?:(?:8(?:7(?:44|60|2[0-258]|5[0145]|1[0-2]|3[0389]|0[1-37])|2(?:9[2357]|8[1-3568])|3(?:86|92)|69[56]|192)|4(?:5(?:6[4-8]|8[13-9]|9[2-578]|7[0-3568])|69[235-7]|39[2-5]|19[25]|498)|0(?:7(?:9[56]|8[1256])|49[235-8]|29[235])|3(?:19[23]|295|797|892)|1(?:392|511|689|895)|9(?:192|393|494)|719[24]|6493))',
     '400' => '(?:(?:8(?:5(?:8[568]|1[0-25]|4[03-5]|0[12568]|7[01578]|5[025689]|2[15]|6[56]|3[1356])|6(?:01|10|33|66)|794)|0(?:2(?:80|9[238])|19[2-6]|49[2358]|39[358]|59[238]|69[235])|159[2-478]))',
     '401' => '(?:(?:0(?:3(?:80|9[5-8])|59[257]|292)|8[56]01))',
     '402' => '(?:85(?:01|55))',
@@ -385,7 +385,7 @@ our %ZIP_TABLE = (
     '409' => '(?:(?:3(?:8(?:9[2-8]|8[01357-9])|39[23]|79[23]|293|692)|2(?:19[2-6]|59[2378]|398|992)|1(?:298|392)|019[2358]))',
     '410' => '(?:(?:8(?:5(?:67|0[148]|2[025]|5[0-258]|8[058]|4[03-5]|3[0135]|7[05]|1[0145])|6(?:10|8[69]|5[45]|0[12])|7(?:10|39))|2(?:39[2-6]|19[2-5]|29[257]|592)|1(?:19[2-7]|39[2-6])|0(?:39[568]|19[25])|3(?:69[36]|292)))',
     '411' => '(?:8(?:5(?:02|33|60|77|88|2[05]|5[15]|[14][01])|6(?:30|89|2[03]|4[148]|6[068]|5[0-2]|1[01])|7(?:[45]0|[78]7|2[025]|3[01])))',
-    '412' => '(?:8(?:5(?:24|50|85|1[1-3]|0[15])|6(?:3[04]|0[159])))',
+    '412' => '(?:8(?:5(?:24|50|85|1[1-3]|0[15])|6(?:3[04]|0[159])|701))',
     '413' => '(?:(?:8(?:5(?:30|8[59]|0[25]|5[058]|6[067]|1[01])|6(?:26|78|1[18]))|0(?:29[238]|49[23]|196)))',
     '414' => '(?:85(?:11|5[05]))',
     '415' => '(?:(?:8(?:5(?:30|0[125-9]|[12][0-8])|6(?:11|0[23]))|0(?:19[2-4]|392)))',
@@ -393,7 +393,7 @@ our %ZIP_TABLE = (
     '417' => '(?:8(?:5(?:6[05-7]|3[01358]|8[058]|0[135-8]|1[0-29]|5[05]|7[0157]|2[029]|4[035])|6(?:[15]0|32|86|0[19])))',
     '418' => '(?:(?:86(?:[68]6|01)|0192))',
     '419' => '(?:0(?:19[23]|29[35]|392))',
-    '420' => '(?:8(?:6(?:6[06]|2[02-48]|4[14]|0[1-468]|7[07]|3[03679]|5[05]|8[01568]|1[0-268])|5(?:70|0[1-357-9]|8[0158]|1[0-25]|6[07]|5[078]|2[0-3578]|3[06-8])|7(?:0[3469]|1[02]|3[389]|4[07]|2[0-2]|6[01])))',
+    '420' => '(?:8(?:6(?:6[06]|2[02-48]|4[14]|0[1-468]|7[07]|3[03679]|5[05]|8[01568]|1[0-268])|5(?:70|0[1-357-9]|8[0158]|1[0-25]|6[07]|5[0578]|2[0-3578]|3[06-8])|7(?:0[3469]|1[02]|3[389]|4[07]|2[0-2]|6[01])))',
     '421' => '(?:(?:0(?:1(?:88|9[23578])|39[2-7]|59[23568]|49[2356]|29[238])|1(?:29[58]|392)|329[25-7]))',
     '422' => '(?:8(?:5(?:[58]0|45|[26]\d|0[24-79]|7[0-8]|3[01]|1[0-24-9])|6(?:5[04]|3[03]|7[07]|8[068]|6[68]|1[059]|2[0-28])|766))',
     '424' => '(?:(?:8(?:6(?:48|50|0[1-3]|7[78]|3[1367]|[68][68]|1[01]|2[024])|7(?:3[04]|2[0147]|5[0-25]|6[07]|0[18]|1[579])|5(?:66|0[23]|5[058]|1[01]))|0(?:19[23]|292)))',
@@ -417,7 +417,7 @@ our %ZIP_TABLE = (
     '443' => '(?:(?:8(?:5(?:55|88)|6[01]1)|019[2-4]))',
     '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|1[0-25-7]|8[1568]|2[02]|4[0235]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[238]|89[23])))',
     '445' => '(?:8(?:5(?:85|1[01]|0[1-35])|60[12]))',
-    '446' => '(?:8(?:5(?:40|1[12478]|5[058]|3[35]|0[1-8]|8[58]|2[02-6])|6(?:35|41|86|0[12])))',
+    '446' => '(?:8(?:5(?:40|1[124578]|5[058]|3[35]|0[1-8]|8[58]|2[02-6])|6(?:35|41|86|0[12])))',
     '447' => '(?:8(?:5(?:0[1-35-7]|1[0-2])|6(?:[18]0|0[1358])))',
     '448' => '(?:8(?:6(?:10|22|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:50|4[23]|3[14]|2[35]|0[16])|731))',
     '449' => '(?:029[23])',
@@ -432,7 +432,7 @@ our %ZIP_TABLE = (
     '458' => '(?:85(?:30|55|[18][015]|0[1258]|2[0-25]|7[01]))',
     '459' => '(?:85(?:[01]1|22|40))',
     '460' => '(?:8(?:6(?:90|7[0-2489]|8[1-9]|6[035-9]|3[0-35-8]|0[1-3568]|5[0135-7]|2[013568]|1[013-9])|4(?:7[02357]|1[125-7]|0[1-8]|8[1-58]|5[0156]|2[0256]|9[01]|3[0-59]|6[0-28]|4[014578])|5(?:5[01589]|[23][0-58]|8[05-8]|4[0135]|7[04578]|0[13-9]|1[0-8]|6[06-8])|3(?:02|6[06]|2[015]|5[018]|3[0138]|8[038]|1[0-24589])|7(?:20|65|91|0[1-46-8]|1[18])|20[1-4]))',
-    '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-29]|0[13-8]|7[57]|4[01]|1[1256])|6(?:66|80|4[015]|0[2358]|5[01458]|3[0169]|2[016]|1[024]|7[0-3568])|7(?:0[36-8]|2[159]|9[58]|1[0457])))',
+    '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-29]|0[13-8]|7[57]|4[01]|1[1256])|6(?:66|80|4[015]|0[2358]|5[01458]|3[0169]|2[016]|1[024]|7[0-3568])|7(?:0[367]|2[159]|9[58]|1[0457])))',
     '462' => '(?:8(?:5(?:2[23]|4[03]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08])|666|739))',
     '463' => '(?:85(?:[18]0|5[057]|2[128]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
     '464' => '(?:8(?:5(?:85|4[05-7]|5[058]|1[12]|6[0167]|2[0-2]|3[01369]|7[017])|6(?:[278]1|0[1-3]|4[134]|3[1-357]|5[0-4]|6[12]|1[0135-7])|710))',
@@ -485,7 +485,7 @@ our %ZIP_TABLE = (
     '513' => '(?:8(?:6(?:[57]0|01|8[06]|3[0-3]|6[016])|5(?:[1-3]0|0[15])|701))',
     '514' => '(?:(?:8(?:5(?:4[0356]|3[0-38]|1[0-58]|8[568]|7[01578]|2[0-2468]|5[02358]|0[1-3578]|6[06-8])|6(?:[01]1|[68]6|3[35]))|2(?:39[23568]|29[2-4]|192)|1(?:29[2-7]|19[235])|039[235-7]))',
     '515' => '(?:(?:8(?:5(?:77|3[03]|2[25]|8[568]|6[67]|1[0135]|5[0578]|0[1359])|688)|2(?:69[23]|592)|059[2568]))',
-    '516' => '(?:(?:8(?:5(?:20|77|5[0-58]|4[3-9]|6[67]|1[12568]|8[18]|0[1-35])|6(?:86|0[12]))|1(?:19[2568]|492)|019[2-48]|2195))',
+    '516' => '(?:(?:8(?:5(?:20|33|77|5[0-58]|4[3-9]|6[67]|1[12568]|8[18]|0[1-35])|6(?:86|0[12]))|1(?:19[2568]|492)|019[2-48]|2195))',
     '517' => '(?:(?:0(?:59[23]|292|494)|85(?:01|1[17])))',
     '518' => '(?:(?:0(?:29[2-6]|49[2-6]|192)|85(?:01|18|33)))',
     '519' => '(?:(?:0(?:19[35-8]|49[2357]|59[2-5]|292|393|696)|3(?:69[2-6]|[24]92)|2(?:59[23]|[17]92)|439[2-6]|529[23]|1192))',
@@ -565,8 +565,8 @@ our %ZIP_TABLE = (
     '597' => '(?:8(?:5(?:22|43|55|8[58]|0[12]|1[15])|686))',
     '598' => '(?:85(?:[13]1|22|40|6[06]|0[389]|5[05]))',
     '599' => '(?:(?:0[23]92|8531))',
-    '600' => '(?:8(?:5(?:4[04]|3[03]|1[19]|5[058]|8[1568]|7[07]|6[067]|2[56]|0[1-35])|6(?:52|65|8[68])|7(?:11|87)))',
-    '601' => '(?:(?:85(?:[25]0|01|42|88|3[03]|1[01])|0(?:292|797)|1(?:192|495)))',
+    '600' => '(?:8(?:5(?:4[04]|3[03]|2[056]|1[19]|5[058]|8[1568]|7[07]|6[067]|0[1-35])|6(?:52|65|8[68])|7(?:11|87)))',
+    '601' => '(?:(?:85(?:01|20|42|88|3[03]|5[09]|1[01])|0(?:292|797)|1(?:192|495)))',
     '602' => '(?:8(?:5(?:[27]0|01|55|66|8[058]|1[01])|611))',
     '603' => '(?:85(?:11|22|55|77|88))',
     '604' => '(?:8(?:5(?:20|8[058]|7[178]|6[07]|5[01568]|1[01]|0[1-358])|666|798))',
@@ -605,6 +605,7 @@ our %ZIP_TABLE = (
     '640' => '(?:(?:8(?:5(?:3[0356]|6[04-7]|7[057]|0[1-357-9]|4[014-6]|5[0-25-8]|2[0245]|1[0-69]|8[0-2589])|6(?:8[67]|6[68]|5[1-79])|787)|0492))',
     '641' => '(?:8(?:5(?:0[189]|1[01])|770))',
     '642' => '(?:8501)',
+    '643' => '(?:8501)',
     '644' => '(?:(?:86(?:55|86)|1292))',
     '645' => '(?:8511)',
     '646' => '(?:(?:8(?:5(?:[01]1|8[058]|4[45]|5[08])|660)|(?:02|1[14])92))',
@@ -612,7 +613,7 @@ our %ZIP_TABLE = (
     '648' => '(?:(?:0(?:2(?:8\d|9[2-8])|198|392)|85(?:41|85)))',
     '649' => '(?:(?:6(?:49[2-4]|59[235]|[126]92)|(?:[04]1|35)92|219[2358]|719[245]))',
     '650' => '(?:8(?:5(?:43|1[015]|5[01589]|2[0-258]|6[057]|3[0369]|7[015-7]|8[04-689]|0[1-35])|6(?:[68][06]|7[07])|7(?:87|94)))',
-    '651' => '(?:(?:8(?:5(?:[58]5|01|67|1[124]|7[05]|2[56])|798)|2(?:1(?:8[0178]|9[4-7])|49[24])|01(?:7[0-2578]|9[35]|8[1578])|1195))',
+    '651' => '(?:(?:8(?:5(?:[58]5|01|67|1[124]|7[05]|2[56])|798)|2(?:1(?:8[0178]|9[4-7])|49[24])|01(?:7[0-2578]|9[35]|8[1578])|1(?:195|596)))',
     '652' => '(?:85(?:[17]0|01|85|5[05]))',
     '653' => '(?:85(?:70|85))',
     '654' => '(?:(?:85(?:70|85)|019[2358]))',
@@ -737,7 +738,7 @@ our %ZIP_TABLE = (
     '778' => '(?:(?:850[13-7]|0[12]95))',
     '779' => '(?:(?:3(?:39[3-5]|[4-6]95|29[58])|1(?:29[235]|19[58])|4(?:[478]95|19[35])|(?:53|2[13])95|019[2-5]))',
     '780' => '(?:8(?:5(?:4[01458]|0[1-9]|2[0-35-9]|3[02-9]|6[0-25-8]|5[03-689]|1[0-8]|7[0-27])|6(?:7[05-7]|6[0-2568]|8\d|0[125])|787))',
-    '781' => '(?:(?:5(?:19[25]|29[25]|79[23]|495)|85(?:21|43|60|1[015]|5[1257])|(?:03|42|1[158])92|2(?:19[2-4]|492)|3(?:49[23]|692)|7185))',
+    '781' => '(?:(?:85(?:21|43|60|88|1[015]|5[1257])|5(?:19[25]|29[25]|79[23]|495)|(?:03|42|1[158])92|2(?:19[2-4]|492)|3(?:49[23]|692)|7185))',
     '782' => '(?:8502)',
     '783' => '(?:85(?:55|0[125-9]))',
     '784' => '(?:850[135])',
@@ -874,7 +875,7 @@ our %ZIP_TABLE = (
     '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|6(?:01|86))|0(?:29[378]|39[38]|198)))',
     '918' => '(?:8(?:5(?:4[03]|5[0568]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|0[1-358]|8[03568])|68[168]))',
     '919' => '(?:(?:0(?:59[24578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
-    '920' => '(?:(?:8(?:5(?:0[1-9]|4[0134]|2[0-25]|3[0135-9]|7[0357]|1[0-3578]|5[0-8]|6[0135-8]|8[035-8])|6(?:2[0-356]|8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|0[17]|9[13-7]|2[0-289]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
+    '920' => '(?:(?:8(?:5(?:0[1-9]|4[0134]|2[0-25]|3[0135-9]|7[0357]|1[0-3578]|5[0-8]|[68][035-8])|6(?:2[0-356]|8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|0[17]|9[13-7]|2[0-289]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
     '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|8[0-489]|0[15-8]|2[035-79]|4[1468]|7[1-79])|6(?:01|50|3[079]|1[126]|2[01])|798))',
     '922' => '(?:(?:8(?:5(?:01|30|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[3-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:5[0-257]|8[0168]|3[013]|2[0158]|0[1-357]|6[067]|7[078]|4[14-6]|1[01])|6(?:50|66|2[06]|4[2-46]|1[0156]|8[68]|0[135689]|3[039]))|1(?:29[2-7]|198)|039[238]))',
@@ -932,7 +933,7 @@ our %ZIP_TABLE = (
     '976' => '(?:85(?:01|10))',
     '979' => '(?:(?:0(?:19[26-8]|69[56])|2(?:39[2-4]|195|792)|1(?:[135]92|495)))',
     '980' => '(?:(?:8(?:4(?:6[06]|5[2-468]|7[78]|8[014-68]|2[0-369]|1[0145]|3[013569]|0[1-3578]|4[235-8])|5(?:1[015]|4[3-6]|2[01569]|0[158]|5[05]|3[13-5]|6[0156]|7[013-9]|8[013578])|6(?:40|5[0-26]|6[018]|0[1258]|3[1-36-9]|2[12]|8[56]|7[017])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
-    '981' => '(?:(?:3(?:6(?:8[0-24-68]|9[237])|2(?:9[23568]|8[078])|1(?:9[2-5]|8[089])|49[4-7]|[35]92)|85(?:33|85|6[03]|7[07]|2[235]|5[0-25-8]|1[01]|4[035]|0[125])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|2192))',
+    '981' => '(?:(?:3(?:6(?:8[0-24-68]|9[237])|2(?:8[078]|9[235-8])|1(?:9[2-5]|8[089])|49[4-7]|[35]92)|85(?:33|85|6[03]|7[07]|2[235]|5[0-25-8]|1[01]|4[035]|0[125])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|2192))',
     '982' => '(?:8(?:5(?:[03]1|44|66|77|2[13]|8[58]|5[15]|1[01])|601|798))',
     '983' => '(?:8(?:5(?:70|4[3-5]|3[357]|8[45]|5[156]|6[05]|1[0237]|2[02378]|0[12467])|6(?:22|39|0[12])))',
     '984' => '(?:8(?:5(?:0[135]|8[045]|7[057]|2[25]|3[389]|6[0178]|1[0-2689]|5[0-3578]|4[035])|6(?:42|54|7[056]|0[13]|8[068]|6[689])))',
